# mothership-cli

[![PyPI version](https://badge.fury.io/py/mothership-cli.svg)](https://badge.fury.io/py/mothership-cli)

**Modular Python project scaffolding CLI for structured, efficient development.**

---

## 🚀 Quick Start

```bash
pip install mothership-cli

startup mothership

mothership my_project
mothership scaffold my_project
mothership push my_project
mothership pull https://github.com/you/repo.git
mothership vaporize my_project
mothership flush git
```
